@@ -13,8 +13,8 @@
 #' @param obj original data or object of class \code{\link{sdcMicroObj-class}}
 #' @param ... see arguments below
 #' \itemize{
-#' \item{xm}{perturbed data}
-#' \item{method}{method IL1 or eigen. More methods are implemented in
+#' \item{xm: }{perturbed data}
+#' \item{method: }{method IL1 or eigen. More methods are implemented in
 #' summary.micro()}}
 #' @return data utility or modified entry for data utility the \code{\link{sdcMicroObj-class}}.
 #' @author Matthias Templ
@@ -87,7 +87,7 @@ dUtilityWORK <- function(x, xm, method = "IL1") {
   if (method == "IL1") {
     a <- x
     for (i in 1:dim(x)[2]) {
-      a[[i]] <- abs((x[[i]] - xm[[i]])/sd(x[[i]], na.rm = TRUE) * sqrt(2))
+      a[[i]] <- abs(x[[i]] - xm[[i]])/(sd(x[[i]], na.rm = TRUE) * sqrt(2))
     }
     infLoss1 <- 1/(dim(x)[2] * dim(x)[1]) * sum(a, na.rm = TRUE)
     return(infLoss1)
