@@ -16,6 +16,8 @@ extern SEXP measure_hierachical(SEXP);
 extern SEXP measure_risk_cpp(SEXP, SEXP, SEXP, SEXP, SEXP, SEXP);
 extern SEXP measure_threshold(SEXP, SEXP);
 extern SEXP _sdcMicro_cpp_calcSuppInds(SEXP, SEXP, SEXP);
+extern SEXP _sdcMicro_microaggregation_argus_cpp(SEXP, SEXP, SEXP);
+extern SEXP _sdcMicro_rankSwap_argus_cpp(SEXP, SEXP);
 
 static const R_CallMethodDef CallEntries[] = {
     {"LocalRecProg_cpp",          (DL_FUNC) &LocalRecProg_cpp,          9},
@@ -26,6 +28,8 @@ static const R_CallMethodDef CallEntries[] = {
     {"measure_risk_cpp",          (DL_FUNC) &measure_risk_cpp,          6},
     {"measure_threshold",         (DL_FUNC) &measure_threshold,         2},
     {"_sdcMicro_cpp_calcSuppInds", (DL_FUNC) &_sdcMicro_cpp_calcSuppInds, 3},
+    {"_sdcMicro_microaggregation_argus_cpp", (DL_FUNC) &_sdcMicro_microaggregation_argus_cpp, 3},
+    {"_sdcMicro_rankSwap_argus_cpp",         (DL_FUNC) &_sdcMicro_rankSwap_argus_cpp,         2},    
     {NULL, NULL, 0}
 };
 
